@@ -10,20 +10,20 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.5.5"
+#define MARIADB_CLIENT_VERSION_STR	"10.5.6"
 #define MARIADB_BASE_VERSION		"mariadb-10.5"
-#define MARIADB_VERSION_ID		100505
+#define MARIADB_VERSION_ID		100506
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100505
-#define MYSQL_SERVER_VERSION            "10.5.5-MariaDB"
+#define MYSQL_VERSION_ID                100506
+#define MYSQL_SERVER_VERSION            "10.5.6-MariaDB"
 
 #define MARIADB_PACKAGE_VERSION "3.1.9"
 #define MARIADB_PACKAGE_VERSION_ID 30109
 #define MARIADB_SYSTEM_TYPE "OpenBSD"
-#define MARIADB_MACHINE_TYPE "amd64"
+#define MARIADB_MACHINE_TYPE "sparc64"
 #define MARIADB_PLUGINDIR "/usr/local/lib/mysql/plugin"
 
 /* mysqld compile time options */
